Struct Eei
Source #[repr(transparent)]
pub struct Eei(pub u32);
Enable Error Interrupt 10
Enable Error Interrupt 10
Enable Error Interrupt 11
Enable Error Interrupt 11
Enable Error Interrupt 12
Enable Error Interrupt 12
Enable Error Interrupt 13
Enable Error Interrupt 13
Enable Error Interrupt 14
Enable Error Interrupt 14
Enable Error Interrupt 15
Enable Error Interrupt 15
Enable Error Interrupt 16
Enable Error Interrupt 16
Enable Error Interrupt 17
Enable Error Interrupt 17
Enable Error Interrupt 18
Enable Error Interrupt 18
Enable Error Interrupt 19
Enable Error Interrupt 19
Enable Error Interrupt 20
Enable Error Interrupt 20
Enable Error Interrupt 21
Enable Error Interrupt 21
Enable Error Interrupt 22
Enable Error Interrupt 22
Enable Error Interrupt 23
Enable Error Interrupt 23
Enable Error Interrupt 24
Enable Error Interrupt 24
Enable Error Interrupt 25
Enable Error Interrupt 25
Enable Error Interrupt 26
Enable Error Interrupt 26
Enable Error Interrupt 27
Enable Error Interrupt 27
Enable Error Interrupt 28
Enable Error Interrupt 28
Enable Error Interrupt 29
Enable Error Interrupt 29
Enable Error Interrupt 30
Enable Error Interrupt 30
Enable Error Interrupt 31
Enable Error Interrupt 31
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.