nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Tcd15Csr

Struct Tcd15Csr 

#[repr(transparent)]
pub struct Tcd15Csr(pub u16);
TCD Control and Status

Tuple Fields

0: u16

Implementations

Source

impl Tcd15Csr

pub const fn start(&self) -> bool

Channel Start

pub const fn set_start(&mut self, val: bool)

Channel Start

pub const fn intmajor(&self) -> bool

Enable an interrupt when major iteration count completes.

pub const fn set_intmajor(&mut self, val: bool)

Enable an interrupt when major iteration count completes.

pub const fn inthalf(&self) -> bool

Enable an interrupt when major counter is half complete.

pub const fn set_inthalf(&mut self, val: bool)

Enable an interrupt when major counter is half complete.

pub const fn dreq(&self) -> bool

Disable Request

pub const fn set_dreq(&mut self, val: bool)

Disable Request

pub const fn esg(&self) -> Tcd15CsrEsg

Enable Scatter/Gather Processing

pub const fn set_esg(&mut self, val: Tcd15CsrEsg)

Enable Scatter/Gather Processing

Enable channel-to-channel linking on major loop complete

Enable channel-to-channel linking on major loop complete

pub const fn active(&self) -> bool

Channel Active

pub const fn set_active(&mut self, val: bool)

Channel Active

pub const fn done(&self) -> bool

Channel Done

pub const fn set_done(&mut self, val: bool)

Channel Done

pub const fn majorlinkch(&self) -> u8

Major Loop Link Channel Number

pub const fn set_majorlinkch(&mut self, val: u8)

Major Loop Link Channel Number

pub const fn bwc(&self) -> Tcd15CsrBwc

Bandwidth Control

pub const fn set_bwc(&mut self, val: Tcd15CsrBwc)

Bandwidth Control