nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Tcd17Dlastsga

Struct Tcd17Dlastsga 

#[repr(transparent)]
pub struct Tcd17Dlastsga(pub u32);
TCD Last Destination Address Adjustment/Scatter Gather Address

Tuple Fields

0: u32

Implementations

Source

impl Tcd17Dlastsga

pub const fn dlastsga(&self) -> u32

Destination last address adjustment, or next memory address TCD for channel (scatter/gather)

pub const fn set_dlastsga(&mut self, val: u32)

Destination last address adjustment, or next memory address TCD for channel (scatter/gather)