nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Tcd20NbytesMloffyes

Struct Tcd20NbytesMloffyes 

#[repr(transparent)]
pub struct Tcd20NbytesMloffyes(pub u32);
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

Tuple Fields

0: u32

Implementations

Source

impl Tcd20NbytesMloffyes

pub const fn nbytes(&self) -> u16

Minor Byte Transfer Count

pub const fn set_nbytes(&mut self, val: u16)

Minor Byte Transfer Count

pub const fn mloff(&self) -> u32

If SMLOE = 1 or DMLOE = 1, this field represents a sign-extended offset applied to the source or destination address to form the next-state value after the minor loop completes.

pub const fn set_mloff(&mut self, val: u32)

If SMLOE = 1 or DMLOE = 1, this field represents a sign-extended offset applied to the source or destination address to form the next-state value after the minor loop completes.

pub const fn dmloe(&self) -> bool

Destination Minor Loop Offset Enable

pub const fn set_dmloe(&mut self, val: bool)

Destination Minor Loop Offset Enable

pub const fn smloe(&self) -> bool

Source Minor Loop Offset Enable

pub const fn set_smloe(&mut self, val: bool)

Source Minor Loop Offset Enable